==> immersiveoverlays-1.4.2%2B1.19.2-fabric-sources.jar: cc/cassian/immersiveoverlays/overlay/SpeedOverlay.java <==
package cc.cassian.immersiveoverlays.overlay;

import cc.cassian.immersiveoverlays.ModClient;
import cc.cassian.immersiveoverlays.compat.ModCompat;
import cc.cassian.immersiveoverlays.compat.OreganizedCompat;
import cc.cassian.immersiveoverlays.config.ModConfig;
import net.minecraft.class_243;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_746;

public class SpeedOverlay {
    public static boolean showSpeed = false;


    //? if >1.20 {
    /*public static void renderGameOverlayEvent(GuiGraphics poseStack) {
    *///?} else {
        public static void renderGameOverlayEvent(class_4587 poseStack) {
     //?}
        if (!showSpeed || !ModConfig.get().speed_enable)
            return;
        var mc = class_310.method_1551();
        if (OverlayHelpers.shouldCancelRender(mc))
            return;

        if (mc.field_1724 == null) return;
        double speed = getSpeed(mc.field_1724);
        String speedText = String.format("%.2f", speed);

        int xOffset = 3;
        int tooltipSize = 21;
        int yPlacement = ModConfig.get().speed_vertical_position;
        int textYPlacement = yPlacement+2;

        int fontWidth = 40;

        int windowWidth = mc.method_22683().method_4486();
        int xPlacement = OverlayHelpers.getPlacement(windowWidth, fontWidth, ModConfig.get().speed_horizontal_position_left);
        // render background
        OverlayHelpers.renderBackground(poseStack, windowWidth, fontWidth, xPlacement, xOffset, yPlacement, tooltipSize, ModConfig.get().speed_horizontal_position_left);
        // render text
        OverlayHelpers.drawString(poseStack, mc.field_1772, speedText, xPlacement-xOffset+10, textYPlacement, ModConfig.get().speed_colour);
        var spriteX = xPlacement-4;
        var spriteY = textYPlacement+10;
        var fast = ModClient.locate("textures/gui/fast.png");
        var slow = ModClient.locate("textures/gui/slow.png");
        class_2960 sprite;
        if (speed>=0.05) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX, spriteY, 7);
        if (speed>=0.08) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+7, spriteY, 7);
        if (speed>=0.14) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+14, spriteY, 7);
        if (speed>=0.28) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+21, spriteY, 7);
        if (speed>0.56) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+28, spriteY, 7);
        if (speed>1) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+35, spriteY, 7);
    }

    public static double getSpeed(class_746 player) {
        double speed;
        if (ModCompat.OREGANIZED && ModConfig.get().compat_oreganized_speed) {
            speed = OreganizedCompat.getSpeed(player);
        } else {
            class_243 deltaMovement = player.method_5668().method_18798();
            speed = Math.max(Math.max(deltaMovement.field_1352, deltaMovement.field_1351), deltaMovement.field_1350);
        }
        return speed;
    }
}

==> immersiveoverlays-1.4.5%2B1.20.1-fabric-sources.jar: cc/cassian/immersiveoverlays/overlay/SpeedOverlay.java <==
package cc.cassian.immersiveoverlays.overlay;

import cc.cassian.immersiveoverlays.ModClient;
import cc.cassian.immersiveoverlays.compat.ModCompat;
import cc.cassian.immersiveoverlays.compat.OreganizedCompat;
import cc.cassian.immersiveoverlays.config.ModConfig;
import net.minecraft.class_243;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_746;

public class SpeedOverlay {
    public static boolean showSpeed = false;


    //? if >1.20 {
    public static void renderGameOverlayEvent(class_332 poseStack) {
    //?} else {
        /*public static void renderGameOverlayEvent(PoseStack poseStack) {
     *///?}
        if (!showSpeed || !ModConfig.get().speed_enable)
            return;
        var mc = class_310.method_1551();
        if (OverlayHelpers.shouldCancelRender(mc))
            return;

        if (mc.field_1724 == null) return;
        double speed = getSpeed(mc.field_1724);
        String speedText = String.format("%.2f", speed);

        int xOffset = 3;
        int tooltipSize = 21;
        int yPlacement = ModConfig.get().speed_vertical_position;
        int textYPlacement = yPlacement+2;

        int fontWidth = 40;

        int windowWidth = mc.method_22683().method_4486();
        int xPlacement = OverlayHelpers.getPlacement(windowWidth, fontWidth, ModConfig.get().speed_horizontal_position_left);
        // render background
        OverlayHelpers.renderBackground(poseStack, windowWidth, fontWidth, xPlacement, xOffset, yPlacement, tooltipSize, ModConfig.get().speed_horizontal_position_left);
        // render text
        OverlayHelpers.drawString(poseStack, mc.field_1772, speedText, xPlacement-xOffset+10, textYPlacement, ModConfig.get().speed_colour);
        var spriteX = xPlacement-4;
        var spriteY = textYPlacement+10;
        var fast = ModClient.locate("textures/gui/fast.png");
        var slow = ModClient.locate("textures/gui/slow.png");
        class_2960 sprite;
        if (speed>=0.05) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX, spriteY, 7);
        if (speed>=0.08) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+7, spriteY, 7);
        if (speed>=0.14) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+14, spriteY, 7);
        if (speed>=0.28) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+21, spriteY, 7);
        if (speed>0.56) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+28, spriteY, 7);
        if (speed>1) sprite = fast; else sprite = slow;
        OverlayHelpers.blitSprite(poseStack, sprite, spriteX+35, spriteY, 7);
    }

    public static double getSpeed(class_746 player) {
        double speed;
        if (ModCompat.OREGANIZED && ModConfig.get().compat_oreganized_speed) {
            speed = OreganizedCompat.getSpeed(player);
        } else {
            class_243 deltaMovement = player.method_5668().method_18798();
            speed = Math.max(Math.max(deltaMovement.field_1352, deltaMovement.field_1351), deltaMovement.field_1350);
        }
        return speed;
    }
}
